@@ -3,11 +3,10 @@
 
 #include "config.h"
 #include <graphics.h>
-#include <quicktime/qtprivate.h>
-#include <quicktime/lqt_codecinfo.h>
 
 #include <lqt_funcprotos.h>
-#include <cmodel_permutation.h>
+#include <quicktime/lqt_codecinfo.h>
+// #include <cmodel_permutation.h>
 
 
 
