@@ -520,7 +520,7 @@ typedef struct
 	int version;
 	long flags;
 	int64_t sample_size;
-	long total_entries;
+long total_entries;
 
 	long entries_allocated;    /* used by the library for allocating a table */
 	quicktime_stsz_table_t *table;
@@ -714,7 +714,6 @@ typedef struct
 	quicktime_elst_t elst;
 } quicktime_edts_t;
 
-
 /* qtvr navg (v1.0) */
 typedef struct {
     int    version;        // Always 1
@@ -1242,6 +1241,36 @@ typedef struct
     long controlSettings;
 } quicktime_obji_t;
 
+/* pdat */
+
+typedef struct
+{
+    int version;
+    int revision;
+    long imageRefTrackIndex;
+    long hotSpotRefTrackIndex;
+    float minPan;
+    float maxPan;
+    float defaultPan;
+    float minTilt;
+    float maxTilt;
+    float defaultTilt;
+    float minFOV;
+    float maxFOV;
+    float defaultFOV;
+    long imageSizeX;
+    long imageSizeY;
+    int imageNumFramesX;
+    int imageNumFramesY;
+    long hotSpotSizeX;
+    long hotSpotSizeY;
+    int hotSpotNumFramesX;
+    int hotSpotNumFramesY;
+    long flags;
+    char panoType[4];
+    long reserved;
+} quicktime_pdat_t;
+
 /* pHdr */
 
 typedef struct
@@ -1274,7 +1303,8 @@ typedef struct
 	int64_t node_size; /* size of node in frames */
 	quicktime_ndhd_t ndhd;
 	quicktime_obji_t obji;
-	} quicktime_qtvr_node_t;
+	quicktime_pdat_t pdat;
+} quicktime_qtvr_node_t;
 
 /* file descriptor passed to all routines */
 
@@ -1378,10 +1408,13 @@ typedef struct
         int (*set_pass)(quicktime_t *file, 
 		int track, int pass, int total_passes,
                               const char * stats_file);
-	int (*flush)(quicktime_t *file, 
+        /* Encode and write remaining stuff before closing */
+        int (*flush)(quicktime_t *file, 
                      int track);
+        /* Resynchronize the codec after seeking */
+        void (*resync)(quicktime_t *file, int track);
 
-	void *priv;
+        void *priv;
 
         /* The followings are for libquicktime only */
         void *module;     /* Needed by libquicktime for dynamic loading */
