@@ -80,16 +80,17 @@ static uint8_t encode_alpha_v408[256] =
 
 
 typedef struct
-{
-	unsigned char *work_buffer;
-} quicktime_v408_codec_t;
+  {
+  uint8_t *buffer;
+  int buffer_alloc;
+  } quicktime_v408_codec_t;
 
 static int delete_codec(quicktime_video_map_t *vtrack)
 {
 	quicktime_v408_codec_t *codec;
 
 	codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-	if(codec->work_buffer) free(codec->work_buffer);
+	if(codec->buffer) free(codec->buffer);
 	free(codec);
 	return 0;
 }
@@ -112,14 +113,13 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
           return 0;
           }
 
-        if(!codec->work_buffer)
-          codec->work_buffer = malloc(width * height * 4);
-        
-	quicktime_set_video_position(file, vtrack->current_position, track);
-	bytes = quicktime_frame_size(file, vtrack->current_position, track);
-	result = !quicktime_read_data(file, codec->work_buffer, bytes);
+        bytes = lqt_read_video_frame(file, &codec->buffer,
+                                     &codec->buffer_alloc,
+                                     vtrack->current_position, NULL, track);
+        if(bytes <= 0)
+          return -1;
 
-        in_ptr = codec->work_buffer;
+        in_ptr = codec->buffer;
 	for(i = 0; i < height; i++)
           {
           out_ptr = row_pointers[i];
@@ -157,10 +157,10 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
           return 0;
           }
                 
-        if(!codec->work_buffer)
-          codec->work_buffer = malloc(width * height * 4);
+        if(!codec->buffer)
+          codec->buffer = malloc(width * height * 4);
 
-        out_ptr = codec->work_buffer;
+        out_ptr = codec->buffer;
 	for(i = 0; i < height; i++)
           {
           in_ptr = row_pointers[i];
@@ -177,7 +177,7 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
           }
         
         quicktime_write_chunk_header(file, trak, &chunk_atom);
-	result = !quicktime_write_data(file, codec->work_buffer, bytes);
+	result = !quicktime_write_data(file, codec->buffer, bytes);
 	quicktime_write_chunk_footer(file, 
 		trak,
 		vtrack->current_chunk,
