@@ -7,16 +7,17 @@
 #include <string.h>
 
 typedef struct
-{
-	unsigned char *work_buffer;
-} quicktime_v410_codec_t;
+  {
+  uint8_t *buffer;
+  int buffer_alloc;
+  } quicktime_v410_codec_t;
 
 static int delete_codec(quicktime_video_map_t *vtrack)
 {
 	quicktime_v410_codec_t *codec;
 
 	codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-	if(codec->work_buffer) free(codec->work_buffer);
+	if(codec->buffer) free(codec->buffer);
 	free(codec);
 	return 0;
 }
@@ -40,17 +41,13 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
           return 0;
           }
 
-        if(!codec->work_buffer)
-		codec->work_buffer = malloc(vtrack->track->tkhd.track_width * 
-			vtrack->track->tkhd.track_height *
-			4);
+        bytes = lqt_read_video_frame(file, &codec->buffer, &codec->buffer_alloc,
+                                     vtrack->current_position, NULL, track);
 
-
-	quicktime_set_video_position(file, vtrack->current_position, track);
-	bytes = quicktime_frame_size(file, vtrack->current_position, track);
-	result = !quicktime_read_data(file, codec->work_buffer, bytes);
-
-        in_ptr = codec->work_buffer;
+        if(bytes <= 0)
+          return -1;
+        
+        in_ptr = codec->buffer;
         
 	for(i = 0; i < height; i++)
           {
@@ -100,10 +97,10 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
           return 0;
           }
 
-        if(!codec->work_buffer)
-          codec->work_buffer = malloc(width * height * 4);
+        if(!codec->buffer)
+          codec->buffer = malloc(width * height * 4);
 
-        out_ptr = codec->work_buffer;
+        out_ptr = codec->buffer;
 	for(i = 0; i < height; i++)
           {
           in_y = (uint16_t*)(row_pointers[0] + i * file->vtracks[track].stream_row_span);
@@ -127,7 +124,7 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
           }
         
 	quicktime_write_chunk_header(file, trak, &chunk_atom);
-	result = !quicktime_write_data(file, codec->work_buffer, bytes);
+	result = !quicktime_write_data(file, codec->buffer, bytes);
 	quicktime_write_chunk_footer(file, 
 		trak,
 		vtrack->current_chunk,
