@@ -38,44 +38,51 @@ void quicktime_update_ixtable(quicktime_t *file,
 	int64_t offset,
 	int size)
 {
-	quicktime_riff_t *riff = file->riff[file->total_riffs - 1];
-	quicktime_movi_t *movi = &riff->movi;
-	quicktime_ix_t *ix = movi->ix[trak->tkhd.track_id - 1];
-	quicktime_ixtable_t *ix_table;
+        quicktime_indx_t *indx = &(trak->strl->indx);
+        
+        quicktime_ix_t *ix = indx->table[indx->table_size-1].ix;
+        quicktime_ixtable_t *ix_table;
 
+        //        fprintf(stderr, "quicktime_update_ixtable %d\n", trak->tkhd.track_id);
+        
 /* Allocation */
 	if(ix->table_size >= ix->table_allocation)
 	{
-		quicktime_ixtable_t *old_table = ix->table;
-		int new_allocation = ix->table_allocation * 2;
-		if(new_allocation < 1) new_allocation = 1;
-		ix->table = calloc(1, sizeof(quicktime_ixtable_t) * new_allocation);
-		if(old_table)
-		{
-			memcpy(ix->table, old_table, sizeof(quicktime_ixtable_t) * ix->table_size);
-			free(old_table);
-		}
-		ix->table_allocation = new_allocation;
+        int new_allocation = ix->table_allocation * 2;
+        if(new_allocation < 1) new_allocation = 1;
+        ix->table = realloc(ix->table, sizeof(quicktime_ixtable_t) * new_allocation);
+        memset(ix->table + ix->table_size, 0,
+               sizeof(quicktime_ixtable_t)*(new_allocation - ix->table_size));
+        ix->table_allocation = new_allocation;
 	}
-
+        
 /* Appendage */
 	ix_table = &ix->table[ix->table_size++];
 	ix_table->relative_offset = offset - ix->base_offset;
-	ix_table->size = size;
+        ix_table->size = size;
+
+        if(!trak->mdia.minf.is_audio &&
+           trak->mdia.minf.stbl.stss.total_entries)
+          {
+          /* If bit 31 of the size is set, we have *no* keyframe */
+          ix_table->size |= 0x80000000;
+          }
 }
 
 
 void quicktime_write_ix(quicktime_t *file,
-	quicktime_ix_t *ix,
-	int track)
-{
+                        quicktime_trak_t * trak)
+  {
 	int i;
-        quicktime_riff_t *riff;
-        quicktime_hdrl_t *hdrl;
         quicktime_strl_t *strl;
         quicktime_indx_t *indx;
+        quicktime_ix_t   *ix;
 
-	quicktime_atom_write_header(file, &ix->atom, ix->tag);
+        strl = trak->strl;
+        indx = &(strl->indx);
+        ix = indx->table[indx->table_size-1].ix;
+        
+        quicktime_atom_write_header(file, &ix->atom, ix->tag);
 
 /* longs per entry */
 	quicktime_write_int16_le(file, ix->longs_per_entry);
@@ -103,13 +110,6 @@ void quicktime_write_ix(quicktime_t *file,
 	quicktime_atom_write_footer(file, &ix->atom);
 
 
-/* Update super index */
-	riff = file->riff[0];
-	hdrl = &riff->hdrl;
-	strl = hdrl->strl[track];
-	indx = &strl->indx;
-
-	quicktime_update_indx(file, indx, ix);
 }
 
 void quicktime_read_ix(quicktime_t *file,
@@ -139,9 +139,19 @@ void quicktime_read_ix(quicktime_t *file,
 	}
 }
 
-
-
-
-
-
-
+void quicktime_ix_dump(quicktime_ix_t *ix)
+  {
+  int i;
+  printf("   table_size:      %d\n", ix->table_size);
+  printf("   longs_per_entry: %d\n", ix->longs_per_entry);
+  printf("   index_type:      %d\n", ix->index_type);
+  printf("   base_offset:     %lld\n", ix->base_offset);
+  printf("   tag:             %s\n", ix->tag);
+  printf("   chunk_id:        %s\n", ix->chunk_id);
+  for(i = 0; i < ix->table_size; i++)
+    {
+    printf("   off: %d, size: %d, k: %d\n", ix->table[i].relative_offset,
+           (ix->table[i].size & 0x7FFFFFFF),
+           !(ix->table[i].size & 0x80000000));
+    }
+  }
