@@ -678,53 +678,118 @@ int quicktime_set_audio_position(quicktime_t *file, int64_t sample, int track)
   }
 
 int quicktime_set_video_position(quicktime_t *file, int64_t frame, int track)
-{
-	int64_t offset, chunk_sample, chunk;
-	quicktime_trak_t *trak;
+  {
+  int64_t chunk_sample, chunk;
+  quicktime_trak_t *trak;
+  quicktime_codec_t * codec;
+  
+  if((track < 0) || (track >= file->total_vtracks))
+    return 0;
 
-	if(track < file->total_vtracks)
-	{
-		trak = file->vtracks[track].track;
-		file->vtracks[track].current_position = frame;
-		quicktime_chunk_of_sample(&chunk_sample, &chunk, trak, frame);
-		file->vtracks[track].current_chunk = chunk;
-		offset = quicktime_sample_to_offset(file, trak, frame);
-		quicktime_set_position(file, offset);
-                file->vtracks[track].timestamp =
-                  quicktime_sample_to_time(&(trak->mdia.minf.stbl.stts),
-                                           frame,
-                                           &(file->vtracks[track].stts_index),
-                                           &(file->vtracks[track].stts_count));
-        }
-	else
-		fprintf(stderr, "quicktime_set_video_position: track >= file->total_vtracks\n");
-	return 0;
-}
+  trak = file->vtracks[track].track;
+
+  if((frame < 0) || (frame >= quicktime_track_samples(file, trak)))
+    return 0;
+  
+  file->vtracks[track].current_position = frame;
+  quicktime_chunk_of_sample(&chunk_sample, &chunk, trak, frame);
+  file->vtracks[track].current_chunk = chunk;
+  
+  file->vtracks[track].timestamp =
+    quicktime_sample_to_time(&(trak->mdia.minf.stbl.stts),
+                             frame,
+                             &(file->vtracks[track].stts_index),
+                             &(file->vtracks[track].stts_count));
+
+  /* Resync codec */
+
+  codec = (quicktime_codec_t*)(file->vtracks[track].codec);
+  if(codec && codec->resync)
+    codec->resync(file, track);
+    
+  return 0;
+  }
 
 void lqt_seek_video(quicktime_t * file, int track, int64_t time)
   {
-  int64_t pos;
-  int64_t offset, chunk_sample, chunk;
+  int64_t frame;
   quicktime_trak_t *trak;
 
-  if(track >= file->total_vtracks)
+  if((track < 0) || (track >= file->total_vtracks))
     return;
-
+  
   trak = file->vtracks[track].track;
+
   file->vtracks[track].timestamp = time;
-  pos =
+  
+  frame =
     quicktime_time_to_sample(&(trak->mdia.minf.stbl.stts),
                              &(file->vtracks[track].timestamp),
                              &(file->vtracks[track].stts_index),
                              &(file->vtracks[track].stts_count));
 
-  file->vtracks[track].current_position = pos;
-  quicktime_chunk_of_sample(&chunk_sample, &chunk, trak, pos);
-  file->vtracks[track].current_chunk = chunk;
-  offset = quicktime_sample_to_offset(file, trak, pos);
-  quicktime_set_position(file, offset);
+  //  fprintf(stderr, "lqt_seek_video: %lld %lld\n", time, frame);
+  
+  quicktime_set_video_position(file, frame, track);
   }
 
+
+#define FRAME_PADDING 128
+
+int lqt_read_video_frame(quicktime_t * file,
+                         uint8_t ** buffer, int * buffer_alloc,
+                         int64_t frame, int64_t * time, int track)
+  {
+  int64_t offset, chunk_sample, chunk;
+  int result;
+  quicktime_trak_t *trak;
+  int len;
+  
+  if((track >= file->total_vtracks) || (track < 0))
+    return 0;
+  
+  trak = file->vtracks[track].track;
+
+  if((frame < 0) || (frame >= quicktime_track_samples(file, trak)))
+    return 0;
+  
+  //  file->vtracks[track].current_position = frame;
+  quicktime_chunk_of_sample(&chunk_sample, &chunk, trak, frame);
+  file->vtracks[track].current_chunk = chunk;
+  offset = quicktime_sample_to_offset(file, trak, frame);
+  quicktime_set_position(file, offset);
+
+  if(time)
+    *time = quicktime_sample_to_time(&(trak->mdia.minf.stbl.stts),
+                                     frame,
+                                     &(file->vtracks[track].stts_index),
+                                     &(file->vtracks[track].stts_count));
+
+  len = quicktime_frame_size(file, frame, track);
+  
+  if(len + FRAME_PADDING > *buffer_alloc)
+    {
+    *buffer_alloc = len + FRAME_PADDING + 1024;
+    *buffer = realloc(*buffer, *buffer_alloc);
+    }
+
+  //  fprintf(stderr, "calling quicktime_read_data\n");
+  result = quicktime_read_data(file, *buffer, len);
+
+  //  fprintf(stderr, "lqt_read_video_frame: %lld %d %d\n",
+  //          offset, len, result);
+
+  if(result < len)
+    {
+    return 0;
+    }
+  memset(*buffer + len, 0, FRAME_PADDING);
+  return len;
+  }
+
+#undef FRAME_PADDING
+
+
 int quicktime_has_audio(quicktime_t *file)
   {
   if(quicktime_audio_tracks(file)) return 1;
@@ -990,7 +1055,9 @@ int quicktime_write_audio(quicktime_t *file,
         return result;
 }
 
-int quicktime_write_frame(quicktime_t *file, unsigned char *video_buffer, int64_t bytes, int track)
+int quicktime_write_frame(quicktime_t *file,
+                          unsigned char *video_buffer,
+                          int64_t bytes, int track)
 {
         int result = 0;
         quicktime_atom_t chunk_atom;
@@ -1004,48 +1071,82 @@ int quicktime_write_frame(quicktime_t *file, unsigned char *video_buffer, int64_
                                         vtrack->current_chunk,
                                         &chunk_atom,
                                         1);
+
+        if(file->vtracks[track].current_position)
+          quicktime_update_stts(&file->vtracks[track].track->mdia.minf.stbl.stts,
+                                file->vtracks[track].current_position-1,
+                                file->vtracks[track].track->mdia.minf.stbl.stts.default_duration);
+        
         file->vtracks[track].current_position++;
         file->vtracks[track].current_chunk++;
         return result;
 }
 
 long quicktime_frame_size(quicktime_t *file, long frame, int track)
-{
-	long bytes = 0;
-	quicktime_trak_t *trak = file->vtracks[track].track;
+  {
+  long bytes = 0;
+  quicktime_trak_t *trak = file->vtracks[track].track;
 
-	if(trak->mdia.minf.stbl.stsz.sample_size)
-	{
-		bytes = trak->mdia.minf.stbl.stsz.sample_size;
-	}
-	else
-	{
-		long total_frames = quicktime_track_samples(file, trak);
-		if(frame < 0) frame = 0;
-		else
-		if(frame > total_frames - 1) frame = total_frames - 1;
-		bytes = trak->mdia.minf.stbl.stsz.table[frame].size;
-	}
+  if(trak->mdia.minf.stbl.stsz.sample_size)
+    {
+    bytes = trak->mdia.minf.stbl.stsz.sample_size;
+    }
+  else
+    {
+    long total_frames = quicktime_track_samples(file, trak);
+    if(frame < 0) frame = 0;
+    else
+      if(frame > total_frames - 1) frame = total_frames - 1;
+    bytes = trak->mdia.minf.stbl.stsz.table[frame].size;
+    }
 
 
-	return bytes;
-}
+  return bytes;
+  }
+
+
+int quicktime_read_frame_init(quicktime_t *file, int track)
+  {
+  int64_t offset;
+  quicktime_trak_t *trak = file->vtracks[track].track;
+  offset = quicktime_sample_to_offset(file, trak, file->vtracks[track].current_position);
+  quicktime_set_position(file, offset);
+  
+  if(quicktime_ftell(file) != file->file_position) 
+    {
+    fseeko(file->stream, file->file_position, SEEK_SET);
+    file->ftell_position = file->file_position;
+    }
+  return 0;
+  }
+
+int quicktime_read_frame_end(quicktime_t *file, int track)
+  {
+  file->file_position = quicktime_ftell(file);
+  file->vtracks[track].current_position++;
+  return 0;
+  }
 
 
 long quicktime_read_frame(quicktime_t *file, unsigned char *video_buffer, int track)
-{
-	int64_t bytes;
-	int result = 0;
+  {
+  int64_t bytes, offset, chunk_sample, chunk;
+  int result = 0;
+  quicktime_trak_t *trak = file->vtracks[track].track;
+    
+  bytes = quicktime_frame_size(file, file->vtracks[track].current_position, track);
 
-	bytes = quicktime_frame_size(file, file->vtracks[track].current_position, track);
+  quicktime_chunk_of_sample(&chunk_sample, &chunk, trak, file->vtracks[track].current_position);
+  file->vtracks[track].current_chunk = chunk;
+  offset = quicktime_sample_to_offset(file, trak, file->vtracks[track].current_position);
+  quicktime_set_position(file, offset);
+          
+  result = quicktime_read_data(file, video_buffer, bytes);
+  lqt_update_frame_position(&file->vtracks[track]);
 
-	quicktime_set_video_position(file, file->vtracks[track].current_position, track);
-	result = quicktime_read_data(file, video_buffer, bytes);
-        lqt_update_frame_position(&file->vtracks[track]);
-
-        if(!result) return 0;
-	return bytes;
-}
+  if(!result) return 0;
+  return bytes;
+  }
 
 long quicktime_get_keyframe_before(quicktime_t *file, long frame, int track)
 {
@@ -1162,23 +1263,6 @@ int quicktime_has_keyframes(quicktime_t *file, int track)
 
 
 
-int quicktime_read_frame_init(quicktime_t *file, int track)
-{
-	quicktime_set_video_position(file, file->vtracks[track].current_position, track);
-	if(quicktime_ftell(file) != file->file_position) 
-	{
-		fseeko(file->stream, file->file_position, SEEK_SET);
-		file->ftell_position = file->file_position;
-	}
-	return 0;
-}
-
-int quicktime_read_frame_end(quicktime_t *file, int track)
-{
-	file->file_position = quicktime_ftell(file);
-	file->vtracks[track].current_position++;
-	return 0;
-}
 
 int quicktime_init_video_map(quicktime_video_map_t *vtrack,
                              quicktime_trak_t *trak,
@@ -1399,7 +1483,7 @@ int quicktime_read_info(quicktime_t *file)
                         }
                 }while(!result && quicktime_position(file) < file->total_length);
 		
-		/* read QTVR sample atoms */
+		/* read QTVR sample atoms -- object */
 		if (lqt_qtvr_get_object_track(file) >= 0)
 		{
 			quicktime_qtatom_t leaf_atom, root_atom;
@@ -1427,7 +1511,36 @@ int quicktime_read_info(quicktime_t *file)
 			
 			quicktime_set_position(file, start_position);
 		}
-
+		
+		/* read QTVR sample atoms  -- panorama */
+		if (lqt_qtvr_get_panorama_track(file) >= 0 && lqt_qtvr_get_qtvr_track(file) >= 0)
+		{
+			quicktime_qtatom_t leaf_atom, root_atom;
+			int64_t start_position = quicktime_position(file);
+			quicktime_set_position(file, file->moov.trak[lqt_qtvr_get_panorama_track(file)]->mdia.minf.stbl.stco.table[0].offset);
+			quicktime_qtatom_read_container_header(file);
+			/* root qtatom "sean" */
+			quicktime_qtatom_read_header(file, &root_atom);
+			
+			do
+			{
+				quicktime_qtatom_read_header(file, &leaf_atom);
+				if(quicktime_qtatom_is(&leaf_atom, "pdat"))
+				{
+					quicktime_read_pdat(file, &file->qtvr_node[0].pdat);					
+				}     
+				else
+				if(quicktime_qtatom_is(&leaf_atom, "ndhd"))
+				{
+					quicktime_read_ndhd(file, &file->qtvr_node[0].ndhd);					
+				}     
+				else
+                                        quicktime_qtatom_skip(file, &leaf_atom);
+			} while(quicktime_position(file) < root_atom.end);
+			
+			quicktime_set_position(file, start_position);
+		}
+		
 		if (lqt_qtvr_get_qtvr_track(file) >= 0)
 		{
 			quicktime_qtatom_t leaf_atom, root_atom;
@@ -1454,13 +1567,17 @@ int quicktime_read_info(quicktime_t *file)
                 quicktime_set_position(file, start_position);
                                                                                                                   
         }
-                                                                                                                  
+        
 /* Initialize track map objects */
         if(got_header)
         {
                 quicktime_init_maps(file);
         }
-                                                                                                                  
+
+        /* Set file type if no ftyp is there */
+        if(file->file_type == LQT_FILE_NONE)
+          file->file_type = LQT_FILE_QT_OLD;
+        
 /* Shut down preload in case of an obsurdly high temp_size */
         quicktime_set_preload(file, 0);
                                                                                                                   
@@ -1480,6 +1597,10 @@ int quicktime_dump(quicktime_t *file)
 	{
 		quicktime_obji_dump(&(file->qtvr_node[0].obji));
 	}
+	if (lqt_qtvr_get_panorama_track(file) >= 0)
+	{
+		quicktime_pdat_dump(&(file->qtvr_node[0].pdat));
+	}
 	if (lqt_qtvr_get_qtvr_track(file) >= 0)
 	{
 		quicktime_ndhd_dump(&(file->qtvr_node[0].ndhd));
@@ -2004,22 +2125,6 @@ int lqt_append_audio_chunk(quicktime_t * file, int track,
   return result ? trak->chunk_sizes[chunk-1] : 0;
   }
 
-int lqt_read_video_frame(quicktime_t * file, int track,
-                         long frame,
-                         uint8_t ** buffer, int * buffer_alloc)
-  {
-  int size;
-  quicktime_set_video_position(file, frame, track);
-  size = quicktime_frame_size(file,  frame, track);
-
-  if(*buffer_alloc < size)
-    {
-    *buffer_alloc = size + 1024;
-    *buffer = realloc(*buffer, *buffer_alloc);
-    }
-  
-  return quicktime_read_data(file, *buffer, size);
-  }
 
 int64_t lqt_last_audio_position(quicktime_t * file, int track)
   {
@@ -2411,7 +2516,7 @@ static struct
 filetypes[] =
   {
       { LQT_FILE_NONE,     "Unknown/Undefined" },
-      { LQT_FILE_QT_OLD,   "Quicktime (old)"   },
+      { LQT_FILE_QT_OLD,   "Quicktime"         },
       { LQT_FILE_QT,       "Quicktime"         },
       { LQT_FILE_AVI,      "AVI"               },
       { LQT_FILE_AVI_ODML, "AVI ODML"          },
